import os
import sys


def str_is_bool(value: str) -> bool:
    if type(value) == str:
        input_str = value.lower()
        return input_str == "true" or input_str == "false"
    else:
        raise TypeError


def str_is_true(value: str) -> bool:
    if type(value) == str:
        input_str = value.lower()
        return input_str == "true"
    else:
        raise TypeError


def str_is_false(value: str) -> bool:
    if type(value) == str:
        input_str = value.lower()
        return input_str == "false"
    else:
        raise TypeError


def bool_to_str(value: bool) -> str:
    if type(value) == bool:
        if value == True:
            output_str = "True"
        else:
            output_str = "False"
        return output_str
    else:
        raise TypeError


def resource_path(relative_path) -> str:
    # So you can add directories to --onefile solution
    # And it finds the data
    if hasattr(sys, '_MEIPASS'):
        return os.path.join(sys._MEIPASS, relative_path)
    return os.path.join(os.path.abspath("/"), relative_path)


def resource_path_test(relative_path) -> str:
    # So you can add directories to --onefile solution
    # And it finds the data
    if hasattr(sys, '_MEIPASS'):
        return os.path.join(sys._MEIPASS, relative_path)
    return os.path.join(os.path.abspath("../"), relative_path)


def limit(value, minvalue, maxvalue):
    if (type(value) == int or type(value) == float) \
            and (type(minvalue) == int or type(minvalue) == float) \
            and (type(maxvalue) == int or type(maxvalue) == float):
        val = value
        if minvalue > maxvalue:
            raise ValueError
        if minvalue > val:
            val = minvalue
        if val > maxvalue:
            val = maxvalue
        return val
    else:
        raise TypeError



import datetime


class Timer:

    def __init__(self, target_time: float):
        self.__start_time = datetime.datetime.now()
        self.__set_time = target_time

    def start_ms(self, target_time: float):
        self.__start_time = datetime.datetime.now()
        self.__set_time = target_time

    # Property time over - Start time defined with start_ms
    def __get_time_over(self) -> bool:
        elapsed_time = datetime.datetime.now() - self.__start_time
        return elapsed_time.microseconds / 1000 >= self.__set_time

    time_over = property(__get_time_over, doc="Returns true if time is over")

    # Property Get Time Stamp of Start Time
    def __get_time_stamp(self) -> datetime.datetime:
        return datetime.datetime.now()

    time_stamp = property(__get_time_stamp, doc="Returns actual time stamp")

    # Property Get Time Stamp of Start Time as String
    def __get_time_stamp_str(self) -> str:
        time = datetime.datetime.now()
        output = time.strftime("%Y%m%d-%H%M%S-%f")
        return output

    time_stamp_str = property(__get_time_stamp_str, doc="Returns Actual time stamp, example: 20210708-075514-612456 "
                                                        "yearmonthday-hhmmss-µs")

    # Property Execution Time as datetime.timedelta
    def __get_execution_time(self) -> datetime.timedelta:
        return datetime.datetime.now() - self.__start_time

    execution_time = property(__get_execution_time, doc="Returns execution time since last start")

    # Property Execution Time ms as float
    def __get_execution_time_ms(self) -> float:
        return self.execution_time.microseconds / 1000

    execution_time_ms = property(__get_execution_time_ms, doc="Returns execution time in ms since last start")

    def __get_remaining_time_ms(self) -> float:
        execution_time_ms = self.__get_execution_time_ms()
        if self.__set_time > execution_time_ms:
            remaining_time_ms = self.__set_time - execution_time_ms
        else:
            remaining_time_ms = 0
        return remaining_time_ms

    remaining_time_ms = property(__get_remaining_time_ms, doc="Returns remaining time in ms since last start")

    def __get_remaining_percent(self) -> float:
        remaining_time_ms = self.__get_remaining_time_ms()
        if remaining_time_ms > 0:
            remaining_percent = remaining_time_ms / self.__set_time * 100
        else:
            remaining_percent = 0
        return remaining_percent

    remaining_percent = property(__get_remaining_percent, doc="Returns remaining time in percent since last start")




import pathlib
from setuptools import setup, find_packages

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

pkg_location = 'src'
pkg_name = 'schwicv'

# This call to setup() does all the work
setup(
    name="schwicv",
    version="0.0.7",
    description="Schwi's Utilities",
    long_description=README,
    long_description_content_type="text/markdown",
    py_modules=[pkg_name],
    url="https://github.com/Schwi88/SchwiCV",
    author="Thomas Schwingenschlögl",
    author_email="office@schwi.at",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    packages=find_packages(where=pkg_location, exclude=['tests']),
    package_dir={'': pkg_location},
    install_requires=[],
    entry_points={
        "console_scripts": []
    },
)
